[vlc-devel] commit: python-ctypes: really accomodate new and old-style exception message getting method ( Olivier Aubert )

git version control git at videolan.org
Thu Sep 3 10:54:03 CEST 2009


vlc | branch: master | Olivier Aubert <olivier.aubert at liris.cnrs.fr> | Thu Sep  3 10:50:34 2009 +0200| [e08aa3c9348be1197171026616bed5df58d0a6cd] | committer: Olivier Aubert 

python-ctypes: really accomodate new and old-style exception message getting method

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=e08aa3c9348be1197171026616bed5df58d0a6cd
---

 bindings/python-ctypes/header.py |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/bindings/python-ctypes/header.py b/bindings/python-ctypes/header.py
index cfe047b..d567b9b 100755
--- a/bindings/python-ctypes/header.py
+++ b/bindings/python-ctypes/header.py
@@ -93,9 +93,9 @@ class LibVLCException(Exception):
 
 # From libvlc_structures.h
 
 # This is version-dependent, depending on the presence of libvlc_exception_get_message.
 
-if hasattr(dll, 'libvlc_exception_get_message'):
+if hasattr(dll, 'libvlc_errmsg'):
     # New-style message passing
     class VLCException(ctypes.Structure):
         """libvlc exception.
@@ -106,7 +106,7 @@ if hasattr(dll, 'libvlc_exception_get_message'):
 
         @property
         def message(self):
-            return dll.libvlc_exception_get_message()
+            return dll.libvlc_errmsg()
 
         def init(self):
             libvlc_exception_init(self)
@@ -93,9 +93,9 @@ class LibVLCException(Exception):
 # From libvlc_structures.h
 
-# This is version-dependent, depending on the presence of libvlc_exception_get_message.
+# This is version-dependent, depending on the presence of libvlc_errmsg
 




More information about the vlc-devel mailing list